# flake8-unused-globals

A flake8 plugin that checks for unused global variables.

This package adds the following warnings:

- `UUG001`: An unused global variable.

There are no configuration options at this time.

It is recommended that users ignore UUG001 in constants modules.
